@@ -114,13 +114,11 @@ bytes_type = bytes
 only_complex_number = (complex,) + numpy_complex_numbers
 only_numbers = (int, float, complex, Decimal) + numpy_numbers
 datetimes = (datetime.datetime, datetime.date, datetime.timedelta, datetime.time)
-uuids = (uuid.UUID, )
+uuids = (uuid.UUID)
 times = (datetime.datetime, datetime.time)
 numbers = only_numbers + datetimes
 booleans = (bool, np_bool_)
 
-basic_types = strings + numbers + uuids + booleans + (type(None), )
-
 IndexedHash = namedtuple('IndexedHash', 'indexes item')
 
 current_dir = os.path.dirname(os.path.abspath(__file__))
@@ -133,7 +131,7 @@ TREE_VIEW = 'tree'
 TEXT_VIEW = 'text'
 DELTA_VIEW = '_delta'
 
-ENUM_INCLUDE_KEYS = ['__objclass__', 'name', 'value']
+ENUM_IGNORE_KEYS = frozenset(['_name_', '_value_', '_sort_order_'])
 
 
 def short_repr(item, max_length=15):
@@ -630,37 +628,27 @@ def get_homogeneous_numpy_compatible_type_of_seq(seq):
         return False
 
 
-def detailed__dict__(obj, ignore_private_variables=True, ignore_keys=frozenset(), include_keys=None):
+def detailed__dict__(obj, ignore_private_variables=True, ignore_keys=frozenset()):
     """
     Get the detailed dictionary of an object.
 
     This is used so we retrieve object properties too.
     """
-    if include_keys:
-        result = {}
-        for key in include_keys:
-            try:
-                value = getattr(obj, key)
-            except Exception:
-                pass
-            else:
-                if not callable(value) or key == '__objclass__':  # We don't want to compare functions, however for backward compatibility, __objclass__ needs to be reported.
-                    result[key] = value
-    else:
-        result = obj.__dict__.copy()  # A shallow copy
-        private_var_prefix = f"_{obj.__class__.__name__}__"  # The semi private variables in Python get this prefix
-        for key in ignore_keys:
-            if key in result or (
-                ignore_private_variables and key.startswith('__') and not key.startswith(private_var_prefix)
-            ):
-                del result[key]
-        for key in dir(obj):
-            if key not in result and key not in ignore_keys and (
-                    not ignore_private_variables or (
-                        ignore_private_variables and not key.startswith('__') and not key.startswith(private_var_prefix)
-                    )
-            ):
-                value = getattr(obj, key)
-                if not callable(value):
-                    result[key] = value
+    result = obj.__dict__.copy()  # A shallow copy
+    private_var_prefix = f"_{obj.__class__.__name__}__"  # The semi private variables in Python get this prefix
+    for key in ignore_keys:
+        if key in result or (
+            ignore_private_variables and key.startswith('__') and not key.startswith(private_var_prefix)
+        ):
+            del result[key]
+    for key in dir(obj):
+        if key not in result and key not in ignore_keys and (
+                not ignore_private_variables or (
+                    ignore_private_variables and not key.startswith('__') and not key.startswith(private_var_prefix)
+                )
+        ):
+            value = getattr(obj, key)
+            if not callable(value):
+                print(f"{key}: {value}")
+                result[key] = value
     return result
