@@ -1,3 +1,4 @@
+import logging
 from collections.abc import Mapping
 from copy import copy
 from ordered_set import OrderedSet
@@ -5,6 +6,8 @@ from deepdiff.helper import (
     RemapDict, strings, short_repr, notpresent, get_type, numpy_numbers, np, literal_eval_extended,
     dict_)
 
+logger = logging.getLogger(__name__)
+
 FORCE_DEFAULT = 'fake'
 UP_DOWN = {'up': 'down', 'down': 'up'}
 
@@ -16,6 +19,7 @@ REPORT_KEYS = {
     "unprocessed",
     "iterable_item_added",
     "iterable_item_removed",
+    "iterable_item_moved",
     "attribute_added",
     "attribute_removed",
     "set_item_removed",
@@ -23,6 +27,8 @@ REPORT_KEYS = {
     "repetition_change",
 }
 
+CUSTOM_FIELD = "__internal:custom:extra_info"
+
 
 class DoesNotExist(Exception):
     pass
@@ -46,6 +52,7 @@ class PrettyOrderedSet(OrderedSet):
     From the perspective of the users of the library, they are dealing with lists.
     Behind the scene, we have ordered sets.
     """
+
     def __repr__(self):
         return '[{}]'.format(", ".join(map(str, self)))
 
@@ -84,14 +91,17 @@ class TreeResult(ResultDict):
         if 'iterable_item_added' in self and not self['iterable_item_added']:
             del self['iterable_item_added']
 
+    def __getitem__(self, item):
+        if item not in self:
+            self[item] = PrettyOrderedSet()
+        return self.get(item)
+
 
 class TextResult(ResultDict):
-
     ADD_QUOTES_TO_STRINGS = True
 
     def __init__(self, tree_results=None, verbose_level=1):
         self.verbose_level = verbose_level
-
         # TODO: centralize keys
         self.update({
             "type_changes": dict_(),
@@ -101,6 +111,7 @@ class TextResult(ResultDict):
             "unprocessed": [],
             "iterable_item_added": dict_(),
             "iterable_item_removed": dict_(),
+            "iterable_item_moved": dict_(),
             "attribute_added": self.__set_or_dict(),
             "attribute_removed": self.__set_or_dict(),
             "set_item_removed": PrettyOrderedSet(),
@@ -127,12 +138,14 @@ class TextResult(ResultDict):
         self._from_tree_unprocessed(tree)
         self._from_tree_default(tree, 'iterable_item_added')
         self._from_tree_default(tree, 'iterable_item_removed')
+        self._from_tree_iterable_item_moved(tree)
         self._from_tree_default(tree, 'attribute_added')
         self._from_tree_default(tree, 'attribute_removed')
         self._from_tree_set_item_removed(tree)
         self._from_tree_set_item_added(tree)
         self._from_tree_repetition_change(tree)
         self._from_tree_deep_distance(tree)
+        self._from_tree_custom_results(tree)
 
     def _from_tree_default(self, tree, report_type):
         if report_type in tree:
@@ -180,7 +193,7 @@ class TextResult(ResultDict):
                     remap_dict.update(old_value=change.t1, new_value=change.t2)
 
     def _from_tree_value_changed(self, tree):
-        if 'values_changed' in tree:
+        if 'values_changed' in tree and self.verbose_level > 0:
             for change in tree['values_changed']:
                 the_changed = {'new_value': change.t2, 'old_value': change.t1}
                 self['values_changed'][change.path(
@@ -188,6 +201,13 @@ class TextResult(ResultDict):
                 if 'diff' in change.additional:
                     the_changed.update({'diff': change.additional['diff']})
 
+    def _from_tree_iterable_item_moved(self, tree):
+        if 'iterable_item_moved' in tree and self.verbose_level > 1:
+            for change in tree['iterable_item_moved']:
+                the_changed = {'new_path': change.path(use_t2=True), 'value': change.t2}
+                self['iterable_item_moved'][change.path(
+                    force=FORCE_DEFAULT)] = the_changed
+
     def _from_tree_unprocessed(self, tree):
         if 'unprocessed' in tree:
             for change in tree['unprocessed']:
@@ -222,17 +242,36 @@ class TextResult(ResultDict):
         if 'repetition_change' in tree:
             for change in tree['repetition_change']:
                 path = change.path(force=FORCE_DEFAULT)
-                self['repetition_change'][path] = RemapDict(change.additional[
-                    'repetition'])
+                self['repetition_change'][path] = RemapDict(
+                    change.additional['repetition']
+                )
                 self['repetition_change'][path]['value'] = change.t1
 
     def _from_tree_deep_distance(self, tree):
         if 'deep_distance' in tree:
             self['deep_distance'] = tree['deep_distance']
 
+    def _from_tree_custom_results(self, tree):
+        for k, _level_list in tree.items():
+            if k not in REPORT_KEYS:
+                if not isinstance(_level_list, PrettyOrderedSet):
+                    continue
+
+                # if len(_level_list) == 0:
+                #     continue
+                #
+                # if not isinstance(_level_list[0], DiffLevel):
+                #     continue
+
+                # _level_list is a list of DiffLevel
+                _custom_dict = {}
+                for _level in _level_list:
+                    _custom_dict[_level.path(
+                        force=FORCE_DEFAULT)] = _level.additional.get(CUSTOM_FIELD, {})
+                self[k] = _custom_dict
+
 
 class DeltaResult(TextResult):
-
     ADD_QUOTES_TO_STRINGS = False
 
     def __init__(self, tree_results=None, ignore_order=None):
@@ -245,6 +284,7 @@ class DeltaResult(TextResult):
             "values_changed": dict_(),
             "iterable_item_added": dict_(),
             "iterable_item_removed": dict_(),
+            "iterable_item_moved": dict_(),
             "attribute_added": dict_(),
             "attribute_removed": dict_(),
             "set_item_removed": dict_(),
@@ -274,6 +314,7 @@ class DeltaResult(TextResult):
         else:
             self._from_tree_default(tree, 'iterable_item_added')
             self._from_tree_default(tree, 'iterable_item_removed')
+            self._from_tree_iterable_item_moved(tree)
         self._from_tree_default(tree, 'attribute_added')
         self._from_tree_default(tree, 'attribute_removed')
         self._from_tree_set_item_removed(tree)
@@ -357,6 +398,13 @@ class DeltaResult(TextResult):
                 for index in repetition['new_indexes']:
                     iterable_items_added_at_indexes[index] = value
 
+    def _from_tree_iterable_item_moved(self, tree):
+        if 'iterable_item_moved' in tree:
+            for change in tree['iterable_item_moved']:
+                the_changed = {'new_path': change.path(use_t2=True), 'value': change.t2}
+                self['iterable_item_moved'][change.path(
+                    force=FORCE_DEFAULT)] = the_changed
+
 
 class DiffLevel:
     """
@@ -529,7 +577,7 @@ class DiffLevel:
     def repetition(self):
         return self.additional['repetition']
 
-    def auto_generate_child_rel(self, klass, param):
+    def auto_generate_child_rel(self, klass, param, param2=None):
         """
         Auto-populate self.child_rel1 and self.child_rel2.
         This requires self.down to be another valid DiffLevel object.
@@ -543,7 +591,7 @@ class DiffLevel:
                 klass=klass, parent=self.t1, child=self.down.t1, param=param)
         if self.down.t2 is not notpresent:
             self.t2_child_rel = ChildRelationship.create(
-                klass=klass, parent=self.t2, child=self.down.t2, param=param)
+                klass=klass, parent=self.t2, child=self.down.t2, param=param if param2 is None else param2)
 
     @property
     def all_up(self):
@@ -573,7 +621,22 @@ class DiffLevel:
     def _format_result(root, result):
         return None if result is None else "{}{}".format(root, result)
 
-    def path(self, root="root", force=None, get_parent_too=False):
+    def get_root_key(self, use_t2=False):
+        """
+        Get the path's root key value for this change
+
+        For example if the path to the element that is reported to have a change in value is root['X'][0]
+        then get_root_key should return 'X'
+        """
+        root_level = self.all_up
+        if(use_t2):
+            next_rel = root_level.t2_child_rel
+        else:
+            next_rel = root_level.t1_child_rel or root_level.t2_child_rel  # next relationship object to get a formatted param from
+
+        return next_rel.param
+
+    def path(self, root="root", force=None, get_parent_too=False, use_t2=False, output_format='str'):
         """
         A python syntax string describing how to descend to this level, assuming the top level object is called root.
         Returns None if the path is not representable as a string.
@@ -583,6 +646,9 @@ class DiffLevel:
         Note: We will follow the left side of the comparison branch, i.e. using the t1's to build the path.
         Using t1 or t2 should make no difference at all, except for the last step of a child-added/removed relationship.
         If it does in any other case, your comparison path is corrupt.
+
+        **Parameters**
+
         :param root: The result string shall start with this var name
         :param force: Bends the meaning of "no string representation".
                       If None:
@@ -593,9 +659,12 @@ class DiffLevel:
                       If 'fake':
                         Will try to produce an output optimized for readability.
                         This will pretend all iterables are subscriptable, for example.
+        :param output_format: The format of the output. The options are 'str' which is the default and produces a
+                              string representation of the path or 'list' to produce a list of keys and attributes
+                              that produce the path.
         """
         # TODO: We could optimize this by building on top of self.up's path if it is cached there
-        cache_key = "{}{}".format(force, get_parent_too)
+        cache_key = "{}{}{}{}".format(force, get_parent_too, use_t2, output_format)
         if cache_key in self._path:
             cached = self._path[cache_key]
             if get_parent_too:
@@ -604,38 +673,51 @@ class DiffLevel:
             else:
                 return self._format_result(root, cached)
 
-        result = parent = param = ""
+        if output_format == 'str':
+            result = parent = param = ""
+        else:
+            result = []
+
         level = self.all_up  # start at the root
 
         # traverse all levels of this relationship
         while level and level is not self:
             # get this level's relationship object
-            next_rel = level.t1_child_rel or level.t2_child_rel  # next relationship object to get a formatted param from
+            if(use_t2):
+                next_rel = level.t2_child_rel
+            else:
+                next_rel = level.t1_child_rel or level.t2_child_rel  # next relationship object to get a formatted param from
 
             # t1 and t2 both are empty
             if next_rel is None:
                 break
 
             # Build path for this level
-            item = next_rel.get_param_repr(force)
-            if item:
-                parent = result
-                param = next_rel.param
-                result += item
-            else:
-                # it seems this path is not representable as a string
-                result = None
-                break
+            if output_format == 'str':
+                item = next_rel.get_param_repr(force)
+                if item:
+                    parent = result
+                    param = next_rel.param
+                    result += item
+                else:
+                    # it seems this path is not representable as a string
+                    result = None
+                    break
+            elif output_format == 'list':
+                result.append(next_rel.param)
 
             # Prepare processing next level
             level = level.down
 
-        if get_parent_too:
-            self._path[cache_key] = (parent, param, result)
-            output = (self._format_result(root, parent), param, self._format_result(root, result))
+        if output_format == 'str':
+            if get_parent_too:
+                self._path[cache_key] = (parent, param, result)
+                output = (self._format_result(root, parent), param, self._format_result(root, result))
+            else:
+                self._path[cache_key] = result
+                output = self._format_result(root, result)
         else:
-            self._path[cache_key] = result
-            output = self._format_result(root, result)
+            output = result
         return output
 
     def create_deeper(self,
@@ -643,6 +725,7 @@ class DiffLevel:
                       new_t2,
                       child_relationship_class,
                       child_relationship_param=None,
+                      child_relationship_param2=None,
                       report_type=None):
         """
         Start a new comparison level and correctly link it to this one.
@@ -651,10 +734,10 @@ class DiffLevel:
         """
         level = self.all_down
         result = DiffLevel(
-            new_t1, new_t2, down=None, up=level, report_type=report_type)
+            new_t1, new_t2, down=None, up=level, report_type=report_type, verbose_level=self.verbose_level)
         level.down = result
         level.auto_generate_child_rel(
-            klass=child_relationship_class, param=child_relationship_param)
+            klass=child_relationship_class, param=child_relationship_param, param2=child_relationship_param2)
         return result
 
     def branch_deeper(self,
@@ -662,6 +745,7 @@ class DiffLevel:
                       new_t2,
                       child_relationship_class,
                       child_relationship_param=None,
+                      child_relationship_param2=None,
                       report_type=None):
         """
         Branch this comparison: Do not touch this comparison line, but create a new one with exactly the same content,
@@ -671,7 +755,7 @@ class DiffLevel:
         """
         branch = self.copy()
         return branch.create_deeper(new_t1, new_t2, child_relationship_class,
-                                    child_relationship_param, report_type)
+                                    child_relationship_param, child_relationship_param2, report_type)
 
     def copy(self):
         """
@@ -791,7 +875,11 @@ class ChildRelationship:
                 resurrected = literal_eval_extended(candidate)
                 # Note: This will miss string-representable custom objects.
                 # However, the only alternative I can currently think of is using eval() which is inherently dangerous.
-            except (SyntaxError, ValueError):
+            except (SyntaxError, ValueError) as err:
+                logger.error(
+                    f'stringify_param was not able to get a proper repr for "{param}". '
+                    "This object will be reported as None. Add instructions for this object to DeepDiff's "
+                    f"helper.literal_eval_extended to make it work properly: {err}")
                 result = None
             else:
                 result = candidate if resurrected == param else None
