@@ -21,19 +21,8 @@ except ImportError:  # pragma: no cover.
     toml = None  # pragma: no cover.
 try:
     import clevercsv
-    csv = None
 except ImportError:  # pragma: no cover.
-    import csv
     clevercsv = None  # pragma: no cover.
-try:
-    import orjson
-except ImportError:  # pragma: no cover.
-    orjson = None
-try:
-    from pydantic import BaseModel as PydanticBaseModel
-except ImportError:  # pragma: no cover.
-    PydanticBaseModel = None
-
 from copy import deepcopy
 from functools import partial
 from collections.abc import Mapping
@@ -190,7 +179,7 @@ class SerializationMixin:
             '{"type_changes": {"root": {"old_type": "A", "new_type": "B", "old_value": "obj A", "new_value": "obj B"}}}'
         """
         dic = self.to_dict(view_override=TEXT_VIEW)
-        return json_dumps(dic, default_mapping=default_mapping, **kwargs)
+        return json.dumps(dic, default=json_convertor_default(default_mapping=default_mapping), **kwargs)
 
     def to_dict(self, view_override=None):
         """
@@ -311,7 +300,7 @@ class _RestrictedPickler(pickle.Pickler):
         return None
 
 
-def pickle_dump(obj, file_obj=None, protocol=4):
+def pickle_dump(obj, file_obj=None):
     """
     **pickle_dump**
     Dumps the obj into pickled content.
@@ -329,21 +318,21 @@ def pickle_dump(obj, file_obj=None, protocol=4):
     """
     file_obj_passed = bool(file_obj)
     file_obj = file_obj or io.BytesIO()
-    _RestrictedPickler(file_obj, protocol=protocol, fix_imports=False).dump(obj)
+    # We expect at least python 3.5 so protocol 4 is good.
+    _RestrictedPickler(file_obj, protocol=4, fix_imports=False).dump(obj)
     if not file_obj_passed:
         return file_obj.getvalue()
 
 
-def pickle_load(content=None, file_obj=None, safe_to_import=None):
+def pickle_load(content, safe_to_import=None):
     """
     **pickle_load**
     Load the pickled content. content should be a bytes object.
 
     **Parameters**
 
-    content : Bytes of pickled object. 
-
-    file_obj : A file object to load the content from
+    content : Bytes of pickled object. It needs to have Delta header in it that is
+        separated by a newline character from the rest of the pickled object.
 
     safe_to_import : A set of modules that needs to be explicitly allowed to be loaded.
         Example: {'mymodule.MyClass', 'decimal.Decimal'}
@@ -362,13 +351,9 @@ def pickle_load(content=None, file_obj=None, safe_to_import=None):
 
 
     """
-    if not content and not file_obj:
-        raise ValueError('Please either pass the content or the file_obj to pickle_load.') 
     if isinstance(content, str):
         content = content.encode('utf-8')
-    if content:
-        file_obj = io.BytesIO(content)
-    return _RestrictedUnpickler(file_obj, safe_to_import=safe_to_import).load()
+    return _RestrictedUnpickler(io.BytesIO(content), safe_to_import=safe_to_import).load()
 
 
 def _get_pretty_form_text(verbose_level):
@@ -423,7 +408,7 @@ def load_path_content(path, file_type=None):
         file_type = path.split('.')[-1]
     if file_type == 'json':
         with open(path, 'r') as the_file:
-            content = json_loads(the_file.read())
+            content = json.load(the_file)
     elif file_type in {'yaml', 'yml'}:
         if yaml is None:  # pragma: no cover.
             raise ImportError('Pyyaml needs to be installed.')  # pragma: no cover.
@@ -439,11 +424,9 @@ def load_path_content(path, file_type=None):
             content = the_file.read()
             content = pickle_load(content)
     elif file_type in {'csv', 'tsv'}:
-        if clevercsv:  # pragma: no cover.
-            content = clevercsv.read_dicts(path)
-        else:
-            with open(path, 'r') as the_file:
-                content = list(csv.DictReader(the_file))
+        if clevercsv is None:  # pragma: no cover.
+            raise ImportError('CleverCSV needs to be installed.')  # pragma: no cover.
+        content = clevercsv.read_dicts(path)
         logger.info(f"NOTE: CSV content was empty in {path}")
 
         # Everything in csv is string but we try to automatically convert any numbers we find
@@ -487,8 +470,7 @@ def save_content_to_path(content, path, file_type=None, keep_backup=True):
 def _save_content(content, path, file_type, keep_backup=True):
     if file_type == 'json':
         with open(path, 'w') as the_file:
-            content = json_dumps(content)
-            the_file.write(content)
+            content = json.dump(content, the_file)
     elif file_type in {'yaml', 'yml'}:
         if yaml is None:  # pragma: no cover.
             raise ImportError('Pyyaml needs to be installed.')  # pragma: no cover.
@@ -503,13 +485,11 @@ def _save_content(content, path, file_type, keep_backup=True):
         with open(path, 'wb') as the_file:
             content = pickle_dump(content, file_obj=the_file)
     elif file_type in {'csv', 'tsv'}:
-        if clevercsv:  # pragma: no cover.
-            dict_writer = clevercsv.DictWriter
-        else:
-            dict_writer = csv.DictWriter
+        if clevercsv is None:  # pragma: no cover.
+            raise ImportError('CleverCSV needs to be installed.')  # pragma: no cover.
         with open(path, 'w', newline='') as csvfile:
             fieldnames = list(content[0].keys())
-            writer = dict_writer(csvfile, fieldnames=fieldnames)
+            writer = clevercsv.DictWriter(csvfile, fieldnames=fieldnames)
             writer.writeheader()
             writer.writerows(content)
     else:
@@ -518,15 +498,8 @@ def _save_content(content, path, file_type, keep_backup=True):
     return content
 
 
-def _serialize_decimal(value):
-    if value.as_tuple().exponent == 0:
-        return int(value)
-    else:
-        return float(value)
-
-
 JSON_CONVERTOR = {
-    decimal.Decimal: _serialize_decimal,
+    decimal.Decimal: float,
     ordered_set.OrderedSet: list,
     type: lambda x: x.__name__,
     bytes: lambda x: x.decode('utf-8'),
@@ -534,9 +507,6 @@ JSON_CONVERTOR = {
     uuid.UUID: lambda x: str(x),
 }
 
-if PydanticBaseModel:
-    JSON_CONVERTOR[PydanticBaseModel] = lambda x: x.dict()
-
 
 def json_convertor_default(default_mapping=None):
     if default_mapping:
@@ -571,20 +541,12 @@ class JSONDecoder(json.JSONDecoder):
 def json_dumps(item, default_mapping=None, **kwargs):
     """
     Dump json with extra details that are not normally json serializable
+
+    Note: I tried to replace json with orjson for its speed. It does work
+    but the output it makes is a byte object and Postgres couldn't directly use it without
+    encoding to str. So I switched back to json.
     """
-    if orjson:
-        indent = kwargs.pop('indent', None)
-        if indent:
-            kwargs['option'] = orjson.OPT_INDENT_2
-        return orjson.dumps(
-            item,
-            default=json_convertor_default(default_mapping=default_mapping),
-            **kwargs).decode(encoding='utf-8')
-    else:
-        return json.dumps(
-            item,
-            default=json_convertor_default(default_mapping=default_mapping),
-            **kwargs)
+    return json.dumps(item, default=json_convertor_default(default_mapping=default_mapping), **kwargs)
 
 
 json_loads = partial(json.loads, cls=JSONDecoder)
